@@ -12,7 +12,7 @@ use Type::Registry ();
 use Type::Tiny qw();
 use Types::Standard qw(Any Dict slurpy);
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # Set truthy value to skip validation for local scope.
 our $DISABLE_VALIDATION = 0;
@@ -140,7 +140,7 @@ __END__
 
 =head1 NAME
 
-Text::Xslate::Bridge::TypeDeclaration - A Type::Tiny based Type Validator in Xslate.
+Text::Xslate::Bridge::TypeDeclaration - A Type Validator in Xslate.
 
 =head1 SYNOPSIS
 
@@ -149,44 +149,56 @@ Text::Xslate::Bridge::TypeDeclaration - A Type::Tiny based Type Validator in Xsl
     );
 
     # @@ template.tx
-    # <:- declare(drink => 'Enum["Cocoa", "Cappuchino", "Tea"]') -:>
-    # May I have a cup of <: $drink :>.
+    # <:- declare(
+    #   user  => 'Some::Model::User',
+    #   drink => 'Enum["Cocoa", "Cappuchino", "Tea"]'
+    # ) -:>
+    # <: user.name :> is drinking a cup of <: $drink :>.
 
     # Success!
-    $xslate->render('template.tx', { drink => 'Cocoa' });
+    $xslate->render('template.tx', {
+        user  => Some::Model::User->new(name => 'pokutuna'),
+        drink => 'Cocoa',
+    });
     # Output:
-    #   May I have a cup of Cocoa.
+    #   pokutuna is drinking a cup of Cocoa.
 
 
     # A string 'Oil' is not a drink
-    is $xslate->render('template.tx', { drink => 'Oil' });
+    $xslate->render('template.tx', {
+        user  => Some::Model::User->new(name => 'pokutuna'),
+        drink => 'Oil',
+    });
     # Output:
     #   <pre class="type-declaration-mismatch">
     #   Declaration mismatch for `drink`
     #     Value "Oil" did not pass type constraint "Enum["Cocoa", "Cappuchino", "Tea"]"
     #   </pre>
-    #   May I have a cup of Oil.
+    #   pokutuna is drinking a cup of Oil.
 
 =head1 DESCRIPTION
 
-Text::Xslate::Bridge::TypeDeclaration is a type validator module in L<Text::Xslate> templates.
+Text::Xslate::Bridge::TypeDeclaration is a type validator module for L<Text::Xslate> templates.
 
-The type validation of this module is base on L<Type::Tiny>.
+Type validation of this module is base on L<Type::Tiny>.
 
 L<Type::Tiny> type constraints are compatible with Moo, Moose and Mouse.
 
-C<< declare >> interface was implemented with reference to L<Smart::Args>.
+You can use this even if you do not use these type libraries.
+
+If the library-based type is not found, treats as a class type of the name.
+
 
 =head1 DECLARATIONS
 
+This module looks for a type name that was written in the template from L<Text::Xslate::Bridge::TypeDeclaration::Registry> by default.
+
+The following behaviors can be replaced by specifying the registry in C<registry_class_name> option.
+
 =head2 Types::Standard
 
 See L<Types::Standard>.
 
-These are imported by default L<Text::Xslate::Bridge::TypeDeclaration::Registry>.
-
-You can not use them unless you import L<Types::Standard> with specifying registry by C<< registry_class >> option.
-
 =over 4
 
 =item C<< declare(name => 'Str') >>
@@ -199,7 +211,7 @@ You can not use them unless you import L<Types::Standard> with specifying regist
 
 =head2 Class-Type
 
-These are defined by default L<Text::Xslate::Bridge::TypeDeclaration::Registry> when a name is not found in registry.
+It will be treated as a class type when a type of the given name is not found.
 
 =over 4
 
